% Sergio's Olives study - 2019-09-10

clear all
clc

global B_backup; % this one is for storing B in case iterations are interrupted with ctrl-c


%% ****************************  loading data  ****************************


EstimOpt.DataFile = ('olive_data_1.mat');
DATA = load(EstimOpt.DataFile);

DATA2 = load('data_SB_dummy');
DATA.SBdummy = zeros(size(DATA.ticket,1),3);
DATA.SBdummy(:,1) = vlookup(DATA.ticket,DATA2.Ticket,DATA2.SB0);
DATA.SBdummy(:,2) = vlookup(DATA.ticket,DATA2.Ticket,DATA2.SB30);
DATA.SBdummy(:,3) = vlookup(DATA.ticket,DATA2.Ticket,DATA2.SB70);
DATA.SBdummy(:,4) = vlookup(DATA.ticket,DATA2.Ticket,DATA2.SB100);
clear DATA2

%% ****************************  data transformations  ****************************


% DATA.ANS = DATA.Y;
DATA.ANS = DATA.Y3;

% unique(DATA.OP)
% 1 - baseline
% 2 - cheap talk (Version 2)
% 3 - scale reminder (Version 3)
% 4 - cheap talk and scale


%% ****************************  model specification  ****************************


DATA.Y = DATA.ANS;

DATA.Xa = [DATA.TAX==0,DATA.ENE == 1,DATA.ENE == 2, ...
    DATA.BIO == 1, DATA.BIO == 2, ...
    DATA.WAT == 1, DATA.WAT == 2, ...
    DATA.ERO == 1, DATA.ERO == 2, ...
    DATA.JOB == 5, DATA.JOB == 10, ...
    -DATA.TAX];

EstimOpt.NamesA = {'ASC - Status quo','Tackling climate change - medium (vs. low)','Tackling climate change - high (vs. low)',...
    'Biodiversity - medium (vs. low)','Biodiversity - high (vs. low)',...
    'Risk of pollution of water resources - medium (vs. low)','Risk of pollution of water resources - high (vs. low)',...
    'Soil erosion - medium (vs. low)','Soil erosion - high (vs. low)',...
    'Agricultural employment - 5% increase','Agricultural employment - 10% increase',...
    '- Cost (EUR / year)'};
% EstimOpt.ProjectName = 'LML_Y3_871_cen';


% DATA.Xm = [DATA.OP==2,DATA.OP==3,DATA.OP==4];
% EstimOpt.NamesM = {'Treatment 2','Treatment 3','Treatment 4'};
% EstimOpt.ProjectName = 'LML_Y_871_Xm_cen';



%% ****************************  specifying input ****************************


DATA.filter = true(size(DATA.ticket));
EstimOpt.ProjectName = 'LML_Y3_remake';

DATA.filter = DATA.SBdummy(:,1) == 0;
EstimOpt.ProjectName = 'LML_Y3_SB0a';

DATA.filter = DATA.SBdummy(:,2) == 0;
EstimOpt.ProjectName = 'LML_Y3_SB30a';

DATA.filter = DATA.SBdummy(:,3) == 0;
EstimOpt.ProjectName = 'LML_Y3_SB70a';

DATA.filter = DATA.SBdummy(:,4) == 0;
EstimOpt.ProjectName = 'LML_Y3_SB100a';


INPUT.Y = DATA.Y(DATA.filter);
INPUT.Xa = DATA.Xa(DATA.filter,:);
% INPUT.Xm = DATA.Xm(DATA.filter,:);


%% ****************************  sample characteristics ****************************


EstimOpt.NCT = 6; % Number of choice tasks per person
EstimOpt.NAlt = 3; % Number of alternatives
EstimOpt.NP = length(INPUT.Y)/EstimOpt.NCT/EstimOpt.NAlt; % Number of respondents


EstimOpt.NRep = 1e4; % number of draws for numerical simulation

% INPUT.Xm = DATA.Xm(1:EstimOpt.NAlt*EstimOpt.NCT:end,:);
% INPUT.Xm = reshape(permute(INPUT.Xm(:,:,ones(1, EstimOpt.NRep)),[3 1 2]), [EstimOpt.NRep*EstimOpt.NP,3]);
% EstimOpt.StepFun = @(x) Xmfunc(INPUT.Xm, x);


%% **************************** estimation and optimization options ****************************


[INPUT, Results, EstimOpt, OptimOpt] = DataCleanDCE(INPUT,EstimOpt);


% try

%% ****************************     LML     ****************************

EstimOpt.WTP_space = 1;

n = 1.80;
% W MXL_d(n) x x.xx:
% Y:
% B_backup = [30.1669942260011;14.4112248657674;19.6258970551067;14.7305490796070;19.5666342014247;17.4783409626132;27.1713225562272;10.9315712395355;15.7993935854162;15.7449305560001;26.1772379378736;0.0626965022235620;51.4893042090490;3.04939876917630;11.5738225530262;7.98285870572666;11.9871009958037;3.22903518455238;6.03747170159154;0.487439790119308;6.40408838201669;0.863660265576340;23.9674568606180;0.0276150246616379];
% Y3:
B_backup = [1.76417145710042;0.904549583615136;1.25663978173710;1.05727576799253;1.32018427262837;1.11821041108619;1.83361412948288;0.575069784759021;0.943094501764389;0.914026052661382;1.49268113845070;-0.162691337192624;3.86640787085395;0.464066940963076;1.09066779741328;0.499413336320033;1.03174361855047;0.118264522826006;0.793579412322568;0.260166371141499;0.624430111001452;-0.00585073710234539;2.13868025975747;-0.465765370679246]*10;

EstimOpt.Bounds = [B_backup(1:12) - n*abs(B_backup(13:24)), B_backup(1:12) + n*abs(B_backup(13:24))];

EstimOpt.Bounds(end,1) = eps;

EstimOpt.NGrid = 1e4;
EstimOpt.NRep = 1e4;

EstimOpt.RealMin = 0;
EstimOpt.HessEstFix = 0;
EstimOpt.PlotIndx = 0;
OptimOpt.MaxIter = 1e4;

load('results_LML_0.mat','Betas') % Best results for each specification
% load('results_LML_30.mat','Betas') % Best results for each specification
% load('results_LML_70.mat','Betas') % Best results for each specification
load('results_LML_100_871.mat','Betas') % Best results for each specification

% 
% % Y3: 871 cen: -3695.0890
EstimOpt.NOrder = 8;
EstimOpt.Dist = 7;
EstimOpt.FullCov = 1;
% B_backup = [-2.71458557619112;0.0328300536411851;0.0830073417408539;2.42129333288710;3.55721894586354;-1.80770960917155;4.03705032976277;2.69905667895005;-2.86035602559794;-5.76896907144898;-4.50333346639905;27.6026371126557;-0.982711493832243;0.886064570307195;-0.419685851958387;3.49552760485581;4.79544098512810;-0.0127706755253954;5.03808046194394;1.43155868274328;-0.663698835740163;-4.36134494316450;-0.506990294900085;1.37436130270861;-0.402901340576746;1.16892294573999;0.407181313074023;0.961116031264130;5.56105431723118;0.854558578706658;3.30180968922228;2.11591911089888;-0.879685748061578;-3.34690356426440;-2.46402795760220;-2.53831550112170;1.75545765942615;0.487194149340672;0.415747999518146;2.88071995767276;3.95632176759357;0.442237988523478;4.01986854422360;1.35767653010549;-0.579615729738047;-2.58041548254987;0.316275521778924;20.9159878308718;3.30063045805104;1.89948575640382;1.12033573642533;1.88420614466480;3.68183254710940;1.72287880923130;3.24242979426609;1.03815569960666;1.43267560088359;-2.36769018392102;-0.944588835227338;-6.69571912143479;4.23556904798735;1.37228210423962;0.147333918035771;1.89019992445989;2.89460910825990;1.37905166364492;2.37503695157261;1.33430336558391;0.912454815000078;-2.11768206885900;0.547807994102123;6.80987935918861;4.42239483164860;0.649670726434679;1.89927895528014;2.07728225757688;2.57496455913558;1.86860550527263;2.38870913283883;1.42141445335503;1.13947747140234;-0.720497150788470;0.179230894593165;11.8336562191344;3.56567756580400;-0.294720565651875;-1.78150349087925;1.45061549022506;-1.07634103849141;0.535437566211991;1.83138130740736;-0.215944342265620;0.797767530809796;-2.79467509681274;-3.11890522813570;3.98929620911451;5.84021510532086;0.396366035867332;-1.37887281042355;0.614880242733411;2.42203764180945;-713.537194512116;0.0278787948672092;0.811661556759251;1.65257549280732;-2.63116522632270;-0.269031642866423;7.51241759513514;2.40903589962535;-4.94884084743804;2.89368786451108;-4.45963596253830;-20.1669220523083;2.46257812916635;5.22167870439996;-11.5707837826762;2.67579444578457;-11.1109629719407;14.9115723885298;-4.77968657443351;-5.52192469708540;1.91815907112242;8.32521468127537;2.14588685625924;2.33618579842628;-8.30951912601563;-8.22696890776967;8.30064274905691;1.90217669141025;-2.16236292120817;9.52541238243817;-1.56817283405690;3.41170315693000;1.64037286304771;-2.45848830601751;-2.54907211214876;3.40315729017401;-4.09129400526626;1.63830229409273;8.40887393078727;-2.96448638612676;3.53106516186055;-6.62936780449956;4.55524470328126;1.22371679325300;13.1742398510381;0.331645152657348;3.28750760001936;-3.51008856265236;2.12477671621736;-2.03026835774551;1.67613326169859;6.76745258741127;3.46606748396173;6.25746340852322;-4.45438495254054;-3.30285716025548;-11.3185146272895;-0.432484777041596;-2.27357026493666;5.08063150712819;-0.158849732227900;1.73662054239675;-0.865352342619980;4.76337415064166;-6.63920750824167;-0.193218863580489;-7.32251285153635;6.05682195226433;-3.78159166409129;11.9460257913024;1.11830592130994;-11.0260156977951;0.274747113528571];


% % SB0, SB30:
% EstimOpt.NOrder = 10;
% EstimOpt.Dist = 5;
% EstimOpt.FullCov = 1;
% 
% % SB70:
% EstimOpt.NOrder = 9;
% EstimOpt.Dist = 6;
% EstimOpt.FullCov = 1;

B_backup = Betas(EstimOpt.NOrder-1,:,EstimOpt.Dist-1,EstimOpt.FullCov+1);
B_backup(isnan(B_backup)) = [];






% B_backup(B_backup>100) = 100;
% B_backup(B_backup<-100) = -100;


try
    
% OptimOpt.Algorithm = 'trust-region'; % 'quasi-newton';
% OptimOpt.Hessian = 'user-supplied'; % 'off'
% 
% Results.LML = LML(INPUT,Results,EstimOpt,OptimOpt);

OptimOpt.Algorithm = 'quasi-newton';
OptimOpt.Hessian = 'off';

Results.LML = LML(INPUT,Results,EstimOpt,OptimOpt);


sendmail('mik@czaj.org','MATLAB: D3 - done!');
    
catch theErrorInfo
    
sendmail('mik@czaj.org','MATLAB: D3 - error!');
rethrow(theErrorInfo)

end

% [WTP, WTP_diff, WTP_joint_test] = LML_wtpxm(Results.LML, zeros(1,3), eye(3), 100000);

% Results.LML.b_mtx = [];
% save results_Y_871_Xm_cen
