% Sergio's Olives study - 2019-09-10

clear all
clc

global B_backup; % this one is for storing B in case iterations are interrupted with ctrl-c


%% ****************************  loading data  ****************************


EstimOpt.DataFile = ('olive_data_1.mat');
DATA = load(EstimOpt.DataFile);


%% ****************************  data transformations  ****************************


% DATA.ANS = DATA.Y;
DATA.ANS = DATA.Y3;

% unique(DATA.OP)
% 1 - baseline
% 2 - cheap talk (Version 2)
% 3 - scale reminder (Version 3)
% 4 - cheap talk and scale


%% ****************************  model specification  ****************************


DATA.Y = DATA.ANS;

DATA.Xa = [DATA.TAX==0,DATA.ENE == 1,DATA.ENE == 2, ...
    DATA.BIO == 1, DATA.BIO == 2, ...
    DATA.WAT == 1, DATA.WAT == 2, ...
    DATA.ERO == 1, DATA.ERO == 2, ...
    DATA.JOB == 5, DATA.JOB == 10, ...
    -DATA.TAX];

EstimOpt.NamesA = {'ASC - Status quo','Tackling climate change - medium (vs. low)','Tackling climate change - high (vs. low)',...
    'Biodiversity - medium (vs. low)','Biodiversity - high (vs. low)',...
    'Risk of pollution of water resources - medium (vs. low)','Risk of pollution of water resources - high (vs. low)',...
    'Soil erosion - medium (vs. low)','Soil erosion - high (vs. low)',...
    'Agricultural employment - 5% increase','Agricultural employment - 10% increase',...
    '- Cost (EUR / year)'};
EstimOpt.ProjectName = 'LML_Y3_871_cen';


% DATA.Xm = [DATA.OP==2,DATA.OP==3,DATA.OP==4];
% EstimOpt.NamesM = {'Treatment 2','Treatment 3','Treatment 4'};
% EstimOpt.ProjectName = 'LML_Y3_871_Xm_cen';



%% ****************************  specifying input ****************************


DATA.filter = true(size(DATA.ticket));

INPUT.Y = DATA.Y(DATA.filter);
INPUT.Xa = DATA.Xa(DATA.filter,:);


%% ****************************  sample characteristics ****************************


EstimOpt.NCT = 6; % Number of choice tasks per person
EstimOpt.NAlt = 3; % Number of alternatives
EstimOpt.NP = length(INPUT.Y)/EstimOpt.NCT/EstimOpt.NAlt; % Number of respondents

EstimOpt.NRep = 1e4; % number of draws for numerical simulation

% INPUT.Xm = DATA.Xm(1:EstimOpt.NAlt*EstimOpt.NCT:end,:);
% INPUT.Xm = reshape(permute(INPUT.Xm(:,:,ones(1, EstimOpt.NRep)),[3 1 2]), [EstimOpt.NRep*EstimOpt.NP,3]);
% EstimOpt.StepFun = @(x) Xmfunc(INPUT.Xm, x);


%% **************************** estimation and optimization options ****************************


[INPUT, Results, EstimOpt, OptimOpt] = DataCleanDCE(INPUT,EstimOpt);


try

%% ****************************     LML     ****************************

EstimOpt.WTP_space = 1;

n = 1.80;
% W MXL_d(n) x x.xx:
% Y:
% B_backup = [30.1669942260011;14.4112248657674;19.6258970551067;14.7305490796070;19.5666342014247;17.4783409626132;27.1713225562272;10.9315712395355;15.7993935854162;15.7449305560001;26.1772379378736;0.0626965022235620;51.4893042090490;3.04939876917630;11.5738225530262;7.98285870572666;11.9871009958037;3.22903518455238;6.03747170159154;0.487439790119308;6.40408838201669;0.863660265576340;23.9674568606180;0.0276150246616379];
% Y3:
B_backup = [1.76417145710042;0.904549583615136;1.25663978173710;1.05727576799253;1.32018427262837;1.11821041108619;1.83361412948288;0.575069784759021;0.943094501764389;0.914026052661382;1.49268113845070;-0.162691337192624;3.86640787085395;0.464066940963076;1.09066779741328;0.499413336320033;1.03174361855047;0.118264522826006;0.793579412322568;0.260166371141499;0.624430111001452;-0.00585073710234539;2.13868025975747;-0.465765370679246]*10;
EstimOpt.Bounds = [B_backup(1:12) - n*abs(B_backup(13:24)), B_backup(1:12) + n*abs(B_backup(13:24))];

EstimOpt.Bounds(end,1) = eps;

EstimOpt.NGrid = 1e4;
EstimOpt.NRep = 1e4;

EstimOpt.RealMin = 0;
EstimOpt.HessEstFix = 0;
EstimOpt.PlotIndx = 0;
OptimOpt.MaxIter = 1e4;

load('results_LML_all_spec_Y3.mat','Betas') % Best results for each specification

% Required specification parameters
EstimOpt.NOrder = 8;
EstimOpt.Dist = 7;
EstimOpt.FullCov = 1;

% LML-search
% 
% EstimOpt.LMLSearchNOrder = 10;
% EstimOpt.LMLSearchNTrials = 10;
% OptimOpt.MaxIter = 1e4;
% 
% Summary = [];
% SimIdx = zeros(EstimOpt.LMLSearchNOrder-1,7,2);
% SimIdx(EstimOpt.NOrder-1,EstimOpt.Dist-1,EstimOpt.FullCov+1) = 1;
% [Betas,Summary,DetailedResults] = LML_search(INPUT,Results,EstimOpt,OptimOpt,Betas,Summary,Results,SimIdx);


% LML
B_backup = Betas(EstimOpt.NOrder-1,:,EstimOpt.Dist-1,EstimOpt.FullCov+1);
B_backup(isnan(B_backup)) = [];

% Y3 871 cen: -3695.0890
B_backup = [-2.71458557619112;0.0328300536411851;0.0830073417408539;2.42129333288710;3.55721894586354;-1.80770960917155;4.03705032976277;2.69905667895005;-2.86035602559794;-5.76896907144898;-4.50333346639905;27.6026371126557;-0.982711493832243;0.886064570307195;-0.419685851958387;3.49552760485581;4.79544098512810;-0.0127706755253954;5.03808046194394;1.43155868274328;-0.663698835740163;-4.36134494316450;-0.506990294900085;1.37436130270861;-0.402901340576746;1.16892294573999;0.407181313074023;0.961116031264130;5.56105431723118;0.854558578706658;3.30180968922228;2.11591911089888;-0.879685748061578;-3.34690356426440;-2.46402795760220;-2.53831550112170;1.75545765942615;0.487194149340672;0.415747999518146;2.88071995767276;3.95632176759357;0.442237988523478;4.01986854422360;1.35767653010549;-0.579615729738047;-2.58041548254987;0.316275521778924;20.9159878308718;3.30063045805104;1.89948575640382;1.12033573642533;1.88420614466480;3.68183254710940;1.72287880923130;3.24242979426609;1.03815569960666;1.43267560088359;-2.36769018392102;-0.944588835227338;-6.69571912143479;4.23556904798735;1.37228210423962;0.147333918035771;1.89019992445989;2.89460910825990;1.37905166364492;2.37503695157261;1.33430336558391;0.912454815000078;-2.11768206885900;0.547807994102123;6.80987935918861;4.42239483164860;0.649670726434679;1.89927895528014;2.07728225757688;2.57496455913558;1.86860550527263;2.38870913283883;1.42141445335503;1.13947747140234;-0.720497150788470;0.179230894593165;11.8336562191344;3.56567756580400;-0.294720565651875;-1.78150349087925;1.45061549022506;-1.07634103849141;0.535437566211991;1.83138130740736;-0.215944342265620;0.797767530809796;-2.79467509681274;-3.11890522813570;3.98929620911451;5.84021510532086;0.396366035867332;-1.37887281042355;0.614880242733411;2.42203764180945;-713.537194512116;0.0278787948672092;0.811661556759251;1.65257549280732;-2.63116522632270;-0.269031642866423;7.51241759513514;2.40903589962535;-4.94884084743804;2.89368786451108;-4.45963596253830;-20.1669220523083;2.46257812916635;5.22167870439996;-11.5707837826762;2.67579444578457;-11.1109629719407;14.9115723885298;-4.77968657443351;-5.52192469708540;1.91815907112242;8.32521468127537;2.14588685625924;2.33618579842628;-8.30951912601563;-8.22696890776967;8.30064274905691;1.90217669141025;-2.16236292120817;9.52541238243817;-1.56817283405690;3.41170315693000;1.64037286304771;-2.45848830601751;-2.54907211214876;3.40315729017401;-4.09129400526626;1.63830229409273;8.40887393078727;-2.96448638612676;3.53106516186055;-6.62936780449956;4.55524470328126;1.22371679325300;13.1742398510381;0.331645152657348;3.28750760001936;-3.51008856265236;2.12477671621736;-2.03026835774551;1.67613326169859;6.76745258741127;3.46606748396173;6.25746340852322;-4.45438495254054;-3.30285716025548;-11.3185146272895;-0.432484777041596;-2.27357026493666;5.08063150712819;-0.158849732227900;1.73662054239675;-0.865352342619980;4.76337415064166;-6.63920750824167;-0.193218863580489;-7.32251285153635;6.05682195226433;-3.78159166409129;11.9460257913024;1.11830592130994;-11.0260156977951;0.274747113528571];


% % Y3 871 Xm cen: -3648.7008
% B_backup = [B_backup; zeros(size(INPUT.Xa,2).*size(INPUT.Xm,2),1)];
% B_backup = [-4.27933346060596;0.488365053531593;0.339354237256194;0.720733343371392;2.94322671055240;-6.55171326072819;4.56130460711682;4.29082575824577;-0.794188835593975;-5.61115556267825;-5.06486107665898;34.0476521455535;-3.22737956822292;0.805148079255866;-0.906476161778237;2.16952574021234;4.51706876704044;-3.23311416976343;3.75936502062208;4.27601903180581;2.49934538960692;-3.25518805454897;-2.30565651885366;2.30207692813612;-1.70311069380396;1.34685974836904;0.369821704291429;1.20661088073327;5.11410247559966;-1.95586059076040;4.42330092288469;3.11267762541359;1.84944265697065;-1.35443760702736;-2.93264642766051;-3.79721750013125;-0.552987499482733;0.604121745577978;-0.146841327120968;2.16620229562259;2.63019910616089;-1.67792928559328;3.62420222528826;3.51941852980846;0.639380917211653;-1.49258304807243;-1.03020962284115;28.7815254101545;1.02090994822673;1.41673941776919;0.448357703647998;2.11685697537497;3.81492864807602;-0.568818825705675;4.32881213577641;1.24596394386675;2.62619012452130;-0.824581468665911;-1.33082612268536;-4.06639173617755;1.22259264627107;0.631522150011532;-0.103441813344923;1.65879100156255;2.87830289858447;-0.184691537273920;2.46406404716743;2.42559261590556;1.39168745950167;-0.596363059620890;-0.215416067573127;-1.84949968418039;2.27889902713779;0.217616688130722;0.443391062297311;2.50268065584051;0.929255469004731;0.293075477761038;3.48158995174248;2.77001451407754;1.26896015944228;0.622748236041269;-1.08708031775879;-43.8097689088139;0.979718742198972;-1.34062212088264;-1.13290989891228;0.792817013508042;2.09179746106655;0.909947828718651;2.39850372301960;0.552750653870944;0.0864572637912786;-2.20655745893733;-1.75268765029263;1.05691827507607;1.06572863784016;-1.29717468896869;-3.20920914287710;2.02476434684071;1.35558168774233;-95.8152812612489;0.522997094981194;1.05273593310459;0.630721471074453;-0.954050412163991;-1.86691929397189;14.3770548871834;3.06782879624832;-5.83680167993825;-0.805771703666818;-6.16893115571458;-17.8662496249100;0.0621530554390418;7.99009889885690;-2.07131894490386;5.48869861962660;-10.6847614745820;17.0801273478285;0.00215858133563624;-3.11140067999607;0.201523260374405;4.53581246641503;6.87620999103210;2.86685556058668;-11.0430644038147;-3.66073122360510;1.50102569677155;7.21082714117673;-2.38098391836640;6.27395304841064;1.28889789779191;7.01430177001716;1.18435654267318;-1.36389060854337;-4.03138840824371;3.27708810487877;-0.233817588032877;1.29562164522060;2.50662746203024;2.26665331720339;2.24772294747690;-2.69768285447371;4.83810399784282;-1.77432841346746;14.7940929078800;-2.07231310366887;4.90094670981918;-5.94262877673820;7.59487401177156;-2.98728548395958;2.32646677705432;5.04638995060025;-4.65472725423402;7.47428336322709;-2.56081701887278;-2.33951845053950;-6.62709069236102;1.99464345961478;-2.13336132989499;0.388709249040889;-2.29460004952576;0.697690500280171;-4.65393718636052;4.88398286422409;-8.29699736735095;4.11697755905109;-10.8649251752912;6.14013809569993;-4.13534610821220;8.30676771793565;3.38221938761287;-20.5585916907752;1.21722075697056;-0.0201764696135490;0.0118966872828713;-0.0704444660324907;-0.297678154285464;-0.0191797352213429;-0.442743977341242;0.0232086518069037;-0.00195129023850354;0.0688247897901578;-0.163762385615934;-0.0299837763382069;0.166809336770824;-0.00940137867873547;-0.114035115748553;-0.0512772355915455;-0.117868209583102;0.0647974385690853;-0.333750958971611;0.0259258415320409;0.381643435734988;0.000775687325082310;13.7883036405141;-0.0288954159733310;0.445045587218311;0.00452230748133501;0.0611889259249179;-0.0669840063220143;-0.174449872606873;0.0659517744541304;0.252516090816799;-0.00289716590165740;0.242653893074234;0.157858350852250;-13.2736539127565;-0.00891721582736064;0.0312518523080690];


OptimOpt.Algorithm = 'trust-region'; % 'quasi-newton';
OptimOpt.Hessian = 'user-supplied'; % 'off'

Results.LML = LML(INPUT,Results,EstimOpt,OptimOpt);

OptimOpt.Algorithm = 'quasi-newton';
OptimOpt.Hessian = 'off';

Results.LML = LML(INPUT,Results,EstimOpt,OptimOpt);


sendmail('mik@czaj.org','MATLAB: BIURO - done!');
    
catch theErrorInfo
    
sendmail('mik@czaj.org','MATLAB: BIURO - error!');
rethrow(theErrorInfo)

end

% [WTP, WTP_diff, WTP_joint_test] = LML_wtpxm(Results.LML, zeros(1,3), eye(3), 100000);

% Results.LML.b_mtx = [];
% save results_Y3_480_Xm_cen

% r1 = reshape(WTP,[11,3*4]);
% r2 = reshape(WTP_diff,[11,3*3]);
% 
% save results_Y3_871_Xm_cen