% Sergio's Olives study - 2019-09-10

clear all
clc

global B_backup; % this one is for storing B in case iterations are interrupted with ctrl-c


%% ****************************  loading data  ****************************


EstimOpt.DataFile = ('olive_data_1.mat');
DATA = load(EstimOpt.DataFile);


%% ****************************  data transformations  ****************************


DATA.ANS = DATA.Y;
% DATA.ANS = DATA.Y3;

% unique(DATA.OP)
% 1 - baseline
% 2 - cheap talk (Version 2)
% 3 - scale reminder (Version 3)
% 4 - cheap talk and scale


%% ****************************  model specification  ****************************


DATA.Y = DATA.ANS;

DATA.Xa = [DATA.TAX==0,DATA.ENE == 1,DATA.ENE == 2, ...
    DATA.BIO == 1, DATA.BIO == 2, ...
    DATA.WAT == 1, DATA.WAT == 2, ...
    DATA.ERO == 1, DATA.ERO == 2, ...
    DATA.JOB == 5, DATA.JOB == 10, ...
    -DATA.TAX];

EstimOpt.NamesA = {'ASC - Status quo','Tackling climate change - medium (vs. low)','Tackling climate change - high (vs. low)',...
    'Biodiversity - medium (vs. low)','Biodiversity - high (vs. low)',...
    'Risk of pollution of water resources - medium (vs. low)','Risk of pollution of water resources - high (vs. low)',...
    'Soil erosion - medium (vs. low)','Soil erosion - high (vs. low)',...
    'Agricultural employment - 5% increase','Agricultural employment - 10% increase',...
    '- Cost (EUR / year)'};
EstimOpt.ProjectName = 'LML_Y_871_cen';


DATA.Xm = [DATA.OP==2,DATA.OP==3,DATA.OP==4];
EstimOpt.NamesM = {'Treatment 2','Treatment 3','Treatment 4'};
EstimOpt.ProjectName = 'LML_Y_871_Xm_cen';



%% ****************************  specifying input ****************************


DATA.filter = true(size(DATA.ticket));

INPUT.Y = DATA.Y(DATA.filter);
INPUT.Xa = DATA.Xa(DATA.filter,:);
INPUT.Xm = DATA.Xm(DATA.filter,:);

%% ****************************  sample characteristics ****************************


EstimOpt.NCT = 6; % Number of choice tasks per person
EstimOpt.NAlt = 3; % Number of alternatives
EstimOpt.NP = length(INPUT.Y)/EstimOpt.NCT/EstimOpt.NAlt; % Number of respondents


EstimOpt.NRep = 1e4; % number of draws for numerical simulation

INPUT.Xm = DATA.Xm(1:EstimOpt.NAlt*EstimOpt.NCT:end,:);
INPUT.Xm = reshape(permute(INPUT.Xm(:,:,ones(1, EstimOpt.NRep)),[3 1 2]), [EstimOpt.NRep*EstimOpt.NP,3]);
EstimOpt.StepFun = @(x) Xmfunc(INPUT.Xm, x);


%% **************************** estimation and optimization options ****************************


[INPUT, Results, EstimOpt, OptimOpt] = DataCleanDCE(INPUT,EstimOpt);


% try

%% ****************************     LML     ****************************

EstimOpt.WTP_space = 1;

n = 1.80;
% W MXL_d(n) x x.xx:
B_backup = [30.1669942260011;14.4112248657674;19.6258970551067;14.7305490796070;19.5666342014247;17.4783409626132;27.1713225562272;10.9315712395355;15.7993935854162;15.7449305560001;26.1772379378736;0.0626965022235620;51.4893042090490;3.04939876917630;11.5738225530262;7.98285870572666;11.9871009958037;3.22903518455238;6.03747170159154;0.487439790119308;6.40408838201669;0.863660265576340;23.9674568606180;0.0276150246616379];
EstimOpt.Bounds = [B_backup(1:12) - n*abs(B_backup(13:24)), B_backup(1:12) + n*abs(B_backup(13:24))];

EstimOpt.Bounds(end,1) = eps;

EstimOpt.NGrid = 1e4;
EstimOpt.NRep = 1e4;

EstimOpt.RealMin = 0;
EstimOpt.HessEstFix = 0;
EstimOpt.PlotIndx = 0;
OptimOpt.MaxIter = 1e4;

load('results_LML_all_spec_Y.mat','Betas') % Best results for each specification

% Required specification parameters
EstimOpt.NOrder = 8;
EstimOpt.Dist = 7;
EstimOpt.FullCov = 1;

B_backup = Betas(EstimOpt.NOrder-1,:,EstimOpt.Dist-1,EstimOpt.FullCov+1);
B_backup(isnan(B_backup)) = [];

% Y 871: -3784.3484
B_backup = [-0.901975842914499;-8.65169642414712;-4.38731376895934;-0.474338071564586;3.73590181551116;-0.277575742672486;-0.743654882414961;-1.63790612436239;3.35243793956967;-3.67692513392877;0.364723839970839;-38.8511878413109;-0.905708330908585;-5.73369503098390;0.618614609416452;-1.67451197919358;-0.143675339468830;0.531994034378355;-2.22876133984547;-1.16473367252367;1.89616154452488;-1.54692741616721;0.409224711364130;-12.2880045338796;0.360039949695043;-5.25207387382474;2.40041945774247;0.437741980756164;2.69004914449819;0.778526513999487;-0.873691565315859;0.526197231861903;2.48831577554168;-3.41280445558759;3.45812627033043;2.11939899723929;2.14735287854752;-12.9542097712179;0.797575107734586;0.236162641794979;3.56059358857885;3.71711635529265;-0.157933403148618;-0.783393284923816;1.53288908804885;-0.862147951548388;3.27926373461442;-3.19118667623028;3.83740687828952;-1.95225120022047;1.93048516560401;0.555502301147243;4.37449413418541;4.08683892305098;-7.67319365958223;0.0472963603021901;3.31178320849775;-1.12985454275314;3.68100220370461;-0.0897534261894327;7.73541193849455;-2.18031163399329;1.54043336239271;-6.87027498065319;3.14552025438059;1.79306968749374;-1.75865913284405;-0.527906769981502;-6.04753389765138;-1.77897822090799;4.06256427554111;2.83787182913948;6.22666463831699;-11.6988382277112;-0.225324173977330;1.88565051403203;1.40622567918751;3.98616923925751;1.71320408929508;-1.08975726500369;1.03255643143638;-2.49629200994080;-1.93283852059741;4.68266911648476;0.886268631622959;-33.0458262356065;-95.7252907376436;0.912961340781522;-0.527343024026304;5.25964029737367;-2.17520899013149;-1.20766957969876;0.370618020444909;-0.643480184016865;1.76500427975848;2.95405384628810;12.5527059610554;-0.911590574564479;-0.812899900695172;1.59797556507107;-1.67832502842945;-52.4725355094460;-0.0306434239141514;-1.43189680189992;0.543627000333065;1.18256516077367;0.0222964760271260;5.93497492941512;-8.21723662448181;-0.657566010545048;0.509990367316430;-13.1937414991666;-17.1453711704801;-1.02083915535941;-1.34530527633237;6.05881968889017;1.53668424762080;-17.0025522439401;8.46251125859019;8.07077981238358;3.43819742901689;-5.46278314412130;-10.9515653969024;0.536718696675581;-0.688669226224787;0.576276836123499;-1.55146722763052;-7.67133683271661;-0.297363968253471;-9.58397763264411;4.21300625974805;8.43334766807262;0.388182035399939;-8.26533511201894;6.53447813653503;-2.62560919812511;11.6212347826719;-10.4343330278479;12.7193805648494;5.74600615995554;-12.4147329748981;4.22674412909701;-1.49263243798592;-7.96267468308421;-1.22392658140276;-2.68948121118458;-4.41185764330802;11.7153336329851;-6.68067909527562;6.00081152767362;0.294123015087464;8.96767852341234;-4.80341361682009;5.46876986399331;6.97079296325144;-5.83870244009396;2.89868658017640;-14.2589206773508;1.89408771879987;-2.07818719501547;1.90214568001468;-1.93243056734088;-5.31699034109404;-3.48043955750154;4.41521966026045;3.93582165477884;0.213231537005504;-0.419748982383776;-1.37000469470655;1.39013969678061;-9.46863106592226;10.7822772871507;-9.76464980731427;8.86663489565156];

% Y Xm 871: 
B_backup = [B_backup; zeros(size(INPUT.Xa,2).*size(INPUT.Xm,2),1)];
B_backup = [-0.772210940169568;-8.61932443904505;-6.99190386645155;-1.67673109431605;4.08655450144459;0.584265899858023;-0.376888242917079;0.0146446689963366;3.81546614629063;-3.69879648561494;-1.17288802479059;-2395.72047825038;-1.03602247110478;-5.65043555018228;0.0926368321431788;-2.77288452216761;-0.0786630721236618;1.17313184757908;-2.32819766405275;-0.374047175202830;2.44809400853326;-1.17662842604138;0.446501569392241;-14.1700134723443;0.454271537743338;-5.51641053349777;2.20905612758781;-0.465325406145693;2.84517921480183;1.00069899436986;-0.869679808108295;1.65450334338091;3.02780805471158;-3.67757941391223;3.41897880757034;2.71437531427270;2.66977381529362;-13.3736499179361;0.474976507870385;-0.0171726521587472;3.87381171399157;4.42815925291293;-0.0803137187380451;-0.113076272782499;1.85739167144291;-0.655209779608555;3.34285192538186;-3.65403477850964;4.24164779907049;-1.76851494060033;1.96806828063091;-0.102471702960956;4.71113204383647;4.10823466124570;-7.80940794420735;0.811470704898519;4.19960671147007;-0.606210690296078;4.12463682930212;0.308470104718665;8.87855015017229;-2.17963479007389;1.21465764944112;-5.50687976212458;3.34601058520675;2.26860551800979;-1.89586920246809;-0.158729134538235;-5.29305938676509;-1.75418400506714;4.62862900397245;3.31971445350869;6.80541896497218;-14.6717539063405;0.145436873545801;1.68550374436389;0.817047641059207;4.07265191441052;2.32137696439968;-0.405673837957258;1.39168779195262;-2.42182295288154;-3.43408360901707;5.11819349494232;0.555952594118374;-59.4275487927092;-100.250032790070;0.896105424999629;-1.06243624928447;5.24295421576660;-2.33305502848454;-1.10994389779282;0.865140597006367;-0.658941513907469;2.35165055331854;3.04664314101924;13.8662205029402;-0.728177625217470;-0.977044890438125;1.23914312491866;-2.14900337192319;-70.9562015969131;-0.0611858076071598;-1.00426388063766;1.08372168087108;1.48717963344363;0.507549598350597;6.47021041985797;-8.68346361483181;-1.50930043617717;0.829047632134296;-14.7717950615539;-17.8780193512835;-0.676326563779860;-3.04270024179506;7.59490322027448;2.90542590382180;-21.5603514216270;10.8509391090856;7.66400398024815;1.93633318144466;-3.05233947495677;-11.1508127728824;-0.0806334776318773;-1.58990052938091;0.157750476915309;-0.700378063983380;-8.04808652102730;-0.252000478245166;-10.6364323731976;6.20183547440993;8.56367930838057;0.583660052483882;-7.91372523156020;7.44633914009106;-4.34175903025797;11.9731244920688;-11.0462893250036;13.2430897258119;6.34329675339249;-13.2420716125482;6.35954850338682;-0.602574218826041;-9.73020684345178;-2.00082040686642;-4.78970537637151;-3.42857066018658;11.8350440556592;-6.55957544073466;4.16080777689887;0.427366501600512;8.56451619887094;-2.97608141815120;7.26103237155340;7.27787159262913;-7.66726006599153;6.66411442749698;-17.2229613142474;3.04369896783216;-1.92838345683831;3.55846330876280;-2.92838243403128;-4.29056316962372;-5.89106223479715;4.65084672923056;3.84284773099501;-0.590833807865090;0.408020799993054;-1.32185835277629;2.98918510897929;-12.6422295218841;12.9302307678775;-11.5686247418097;10.1455043060237;-0.00815946836618571;0.0487565247440403;-0.0168915210748310;0.0591703494859793;-0.0604580344283419;-0.0321499646497787;0.0196778829889371;0.204519393457255;0.0596318660263493;-0.0847579930333770;-0.00323684110814389;30.7150020562883;0.00117533122881848;-0.0898818132175186;0.0116318970112649;0.0317897980629224;-0.0602570874714583;0.0457780391668063;-0.00842437897475782;0.331842242803675;0.0881049554570360;-0.0876978231307088;-0.0115242613649837;-4.01873833358300;0.00710142887541947;0.196527077671879;-0.0111452896016691;-0.0255603821901559;0.0147077650849470;0.000925966183139667;-0.0379479188194892;1.24497701436121;-0.0362274296916045;-0.0377441203008667;0.0135658834393862;13.1739966515463];


% EstimOpt.NumGrad = 1;
% EstimOpt.HessEstFix = 1;

try
    
OptimOpt.Algorithm = 'trust-region'; % 'quasi-newton';
OptimOpt.Hessian = 'user-supplied'; % 'off'

Results.LML = LML(INPUT,Results,EstimOpt,OptimOpt);

OptimOpt.Algorithm = 'quasi-newton';
OptimOpt.Hessian = 'off';

Results.LML = LML(INPUT,Results,EstimOpt,OptimOpt);


sendmail('mik@czaj.org','MATLAB: D4 - done!');
    
catch theErrorInfo
    
sendmail('mik@czaj.org','MATLAB: D4 - error!');
rethrow(theErrorInfo)

end

[WTP, WTP_diff, WTP_joint_test] = LML_wtpxm(Results.LML, zeros(1,3), eye(3), 100000);

% Results.LML.b_mtx = [];
% save results_Y_871_Xm_cen
