% Sergio's Olives study - 2017-11-07

clear all
clc

global B_backup; % this one is for storing B in case iterations are interrupted with ctrl-c


%% ****************************  loading data  ****************************


EstimOpt.DataFile = ('olive_data_1.mat');
DATA = load(EstimOpt.DataFile);


%% ****************************  data transformations  ****************************


% DATA.ANS = DATA.Y;
DATA.ANS = DATA.Y3;
% DATA.ANS(~isnan(DATA.Y2)) = DATA.Y2(~isnan(DATA.Y2));

% unique(DATA.OP)
% 1 - baseline
% 2 - cheap talk (Version 2)
% 3 - scale reminder (Version 3)
% 4 - cheap talk and scale

% for i = 1:4
% nanmean(DATA.p4==10 & DATA.OP==i)
% end

% changed = DATA.Y ~= DATA.Y3;
% for i = 1:4
%     nanmean(changed(DATA.OP==i))
% end

%% ****************************  model specification  ****************************


DATA.Y = DATA.ANS;

DATA.Xa = [DATA.TAX==0,DATA.ENE == 1,DATA.ENE == 2, ...
    DATA.BIO == 1, DATA.BIO == 2, ...
    DATA.WAT == 1, DATA.WAT == 2, ...
    DATA.ERO == 1, DATA.ERO == 2, ...
    DATA.JOB == 5, DATA.JOB == 10, ...
    -DATA.TAX/10];

EstimOpt.NamesA = {'ASC - Status quo','Tackling climate change - medium (vs. low)','Tackling climate change - high (vs. low)',...
    'Biodiversity - medium (vs. low)','Biodiversity - high (vs. low)',...
    'Risk of pollution of water resources - medium (vs. low)','Risk of pollution of water resources - high (vs. low)',...
    'Soil erosion - medium (vs. low)','Soil erosion - high (vs. low)',...
    'Agricultural employment - 5% increase','Agricultural employment - 10% increase',...
    '- Cost (10 EUR / year)'};

DATA.Xm = [DATA.OP==2,DATA.OP==3,DATA.OP==4];
EstimOpt.NamesM = {'Treatment 2','Treatment 3','Treatment 4'};

% DATA.Xm = [DATA.OP>1];
% EstimOpt.NamesM = {'Treatment 2-4'};

DATA.Xs = DATA.Xm;
EstimOpt.NamesS = EstimOpt.NamesM;


%% ****************************  specifying input ****************************


DATA.filter = true(size(DATA.ticket));

INPUT.Y = DATA.Y(DATA.filter);
INPUT.Xa = DATA.Xa(DATA.filter,:);
% INPUT.Xm = DATA.Xm(DATA.filter,:);
% INPUT.Xs = DATA.Xs(DATA.filter,:);

% INPUT.W = DATA.W(DATA.filter);

% INPUT.MissingInd = DATA.Missing(DATA.filter,:);


%% ****************************  sample characteristics ****************************


EstimOpt.NCT = 6; % Number of choice tasks per person
EstimOpt.NAlt = 3; % Number of alternatives
EstimOpt.NP = length(INPUT.Y)/EstimOpt.NCT/EstimOpt.NAlt; % Number of respondents


%% **************************** estimation and optimization options ****************************


% EstimOpt.eps = 1.e-9; % overall precision level

[INPUT, Results, EstimOpt, OptimOpt] = DataCleanDCE(INPUT,EstimOpt);

EstimOpt.NRep = 1e4; % number of draws for numerical simulation
% OptimOpt.MaxIter = 1; % maximum number of iterations
% OptimOpt.Algorithm = 'trust-region'; %'quasi-newton'
% EstimOpt.NumGrad = 1; % 1
% OptimOpt.GradObj = 'off'; % 'off'
% OptimOpt.FinDiffType = 'central'; % 'forward'
% OptimOpt.Hessian = 'user-supplied'; % 'off'
% EstimOpt.HessEstFix = 1 ; % 0 = use optimization Hessian, 1 = use jacobian-based (BHHH) Hessian, 2 - use high-precision jacobian-based (BHHH) Hessian 3 - use numerical Hessian


%% ****************************     MNL     ****************************


% try


EstimOpt.WTP_space = 1;

% EstimOpt.ProjectName = '_Y1_jointly';
EstimOpt.ProjectName = '_Y3_jointly';
% EstimOpt.ProjectName = '_Y1_Xm';
% EstimOpt.ProjectName = '_Y3_Xm';


Results.MNL = MNL(INPUT,Results,EstimOpt,OptimOpt);


%% ****************************     MXL_d     ****************************

EstimOpt.Dist = [zeros(size(INPUT.Xa,2)-1,1);1];

% WTP-space Y1: -4104.4072
% B_backup = [2.93369457569005;1.42907192044068;1.97105009749155;1.46024904988533;1.94149820300168;1.72061579767084;2.71324485385777;1.08706395152566;1.56298752308555;1.54500141906536;2.59143124538467;-0.529703229958557;5.19622981150463;0.302244642833080;1.18333067291889;0.760692495019436;1.20881636363149;0.493207877530635;0.433517826935628;-0.0380091124022204;0.683964584374643;0.266887866029814;2.40231663726081;-0.665502159200132];
% Xm: -4089.7614
% B_backup = [B_backup; zeros(size(INPUT.Xa,2).*size(INPUT.Xm,2),1)];
% B_backup = [2.85491822607729;1.57729090045003;1.94334473700992;1.85552641348500;2.27970662345491;1.63985663898349;2.93310334830556;1.17623605420184;1.56745376748049;1.82066098758487;3.14862844695779;-0.657746866536951;5.17145684605990;-0.268232417943158;1.18127200759104;0.635135622212298;1.22617706356521;0.299439313167119;0.663480293110227;0.0121108736573803;0.612878334185407;0.436262199880268;2.41395596045947;-0.658315727573371;-0.642623341792987;-0.493059936651922;-0.219640949960708;-0.542688227455596;-0.473294789523817;-0.128425476397618;-0.636897957031944;-0.209043436822243;0.0137045699887010;-0.552630531440657;-1.04750021442695;0.346875032021248;0.553913649704171;-0.118262978765492;0.161348283745136;-0.285687173113344;-0.364480972038048;0.545918506938453;0.154015570763812;-0.0679904908659289;0.100298007565679;-0.415835526839265;-0.907985127808530;0.0128599119136410;0.654649463894906;0.133705982147794;0.221172605134096;-0.625812070027102;-0.419892994680089;0.0166389631380713;-0.313113608028851;0.0330868684510194;-0.129328532849670;-0.0937303152047579;-0.150083799892966;0.154876178358021];

% WTP-space Y3: -3924.2400
B_backup = [1.76417145710042;0.904549583615136;1.25663978173710;1.05727576799253;1.32018427262837;1.11821041108619;1.83361412948288;0.575069784759021;0.943094501764389;0.914026052661382;1.49268113845070;-0.162691337192624;3.86640787085395;0.464066940963076;1.09066779741328;0.499413336320033;1.03174361855047;0.118264522826006;0.793579412322568;0.260166371141499;0.624430111001452;-0.00585073710234539;2.13868025975747;-0.465765370679246];
% Xm: -3907.0701
% B_backup = [B_backup; zeros(size(INPUT.Xa,2).*size(INPUT.Xm,2),1)];
% B_backup = [1.90016599082684;0.986128567035519;1.27408407530392;1.37377045835748;1.53212885340543;1.33692227576303;2.17645342553228;0.703492524854437;1.05598665534828;1.06486757330863;1.82935191407905;-0.220388075844230;3.84240632813359;0.420455145345649;1.08204949919317;0.482880615503670;1.03699394646894;0.0894563440560844;0.799547883996189;0.367710266077393;0.589503907830810;0.0120837390155982;2.11080511160901;-0.472062076379104;-0.644628046678134;-0.200611388954956;-0.119689674627800;-0.415970374560539;-0.340206710664148;-0.307909626351946;-0.463686258352110;-0.156213945354662;-0.00823243276954739;-0.224524372166026;-0.574908622189597;0.168259504172685;-0.170494719964706;-0.343032188919888;-0.0667508448204807;-0.379192654542593;-0.344480744719960;-0.156167214900161;-0.171951193013675;-0.377265156988574;-0.266494669947082;-0.467514886879169;-0.754791065280081;-0.0162080743580601;0.337809356304469;0.210521673337075;0.0945017447771797;-0.404074606824563;-0.154752010149950;-0.380384515888637;-0.693848186439365;-0.0121072421663608;-0.159201367555884;0.0667079186076953;0.0770703039242633;0.121121260018518];

% B_backup = [B_backup; 0;0;0];

OptimOpt.Algorithm = 'trust-region'; % 'quasi-newton';
OptimOpt.Hessian = 'user-supplied'; % 'off'

Results.MXL_d = MXL(INPUT,Results,EstimOpt,OptimOpt);

OptimOpt.Algorithm = 'quasi-newton';
OptimOpt.Hessian = 'off';

Results.MXL_d = MXL(INPUT,Results,EstimOpt,OptimOpt);


%% ****************************     MXL     ****************************


EstimOpt.FullCov = 1;

% WTP-space Y1: -3939.1900
% B_backup = [3.19049351328320;1.52249945464569;1.98816122972549;1.51631668047992;2.10998317798090;1.86742966442306;2.81044211032205;1.20537262086518;1.78359038295620;1.54955142105482;2.72378270092587;-0.0791063685707002;4.46170549785161;0.656916091708562;0.393655820395239;0.336515295382418;0.588743492479399;0.897860122828006;1.12826044852302;0.652767584749073;0.900411479394920;0.547040527244889;0.577949360667935;-0.148598823892859;1.47003540676088;1.36385555529490;1.26054829173007;1.46222873046299;0.870777790740234;1.59641512583727;0.518889380109640;0.869205158973953;-0.0510360650715048;0.652812651802192;-0.698688691139455;0.864692931138238;0.0538550563573852;0.944521442583849;0.362186716439723;1.10598929301757;-0.186167321837579;0.301809339168470;-0.637357870469576;-0.00234581133586831;-0.148661374578142;0.584816858150130;-0.0848258675961616;0.212104774666897;-0.00878912625990753;0.0724118829449404;-0.194399980904152;0.708954657460952;1.75785355923118;-0.0194504258722711;0.219070141865018;1.05946888122957;1.14173558588685;0.233507173932749;0.680499218561541;0.413194795931094;0.693262581916949;0.0640201129111153;0.421973737552413;0.218983021357037;0.183802255673050;0.112363719682347;-0.553687587079561;-1.09526991334798;-0.282752026924952;0.229250445799763;0.0627303740319712;0.336797999416652;0.229118142195479;0.760049714034373;-0.278311292938088;0.0394151911013289;-0.143308600028426;0.184930126914468;-0.186651051379321;0.225336252185321;-0.171160290194255;0.440829116583261;0.249006599896659;0.359193266532503;0.207939589922529;0.987233968321250;0.0282632795129539;0.613229754104832;-0.455200971694610;-0.0392538869535592];
% Xm: -3921.0332
% B_backup = [B_backup; zeros(size(INPUT.Xa,2).*size(INPUT.Xm,2),1)];
% B_backup = [2.75989032779273;1.63430203139948;1.88174372909675;1.77716035253686;2.31388125546834;1.70798649406432;2.81889591968546;1.03178775045583;1.67853152841227;1.72699658192216;3.25597225202203;-0.0845791430178312;4.37646620509297;0.744377631600661;0.438409779243015;0.508151560831957;0.729544262111910;0.904761885558397;1.14395989334768;0.652212463361068;0.871275080434175;0.531842178089104;0.577262377986135;-0.198768472010751;1.34350880792557;1.32842513136241;1.23901571660589;1.44920120637488;0.856073466420476;1.52234337821338;0.480421072456527;0.843122403477202;0.0932498836605551;0.642022158783523;-0.624331051462326;0.825351389350137;0.101272257329983;1.01656863450268;0.315437173139616;1.11374985842836;-0.0832283563031159;0.323017772401255;-0.736801566263528;0.0156336559476763;-0.140438188393553;0.647443710178986;-0.0248363048419442;0.126903512328266;0.0369746130284893;0.205009192437402;-0.247788208578076;0.701858212818539;1.61742094822652;0.0757019012188169;0.195423919398848;0.996104531851640;1.07075313388731;0.243895226348731;0.697885430504268;0.543140654623964;1.08460078597559;-0.0884826442453615;0.196680885362925;0.282895494949223;0.145050214576968;0.122135563544217;-0.505965465843931;-1.00986475126941;-0.354106459941584;0.175475357398244;-0.0819830004934883;0.282690084757510;0.355981818180525;1.19655359171391;-0.424606918225140;0.0600784547694664;-0.116305861952267;0.0806180891797939;-0.589258188997587;0.293097049270853;-0.0856224674579231;0.165535255052860;-0.451500802428023;0.427055398473839;0.0115603354752213;-0.0173477005744911;0.138499175048708;-0.168762158628819;-0.226382026482485;0.0986301797098706;0.00320034517145348;-0.499730348941887;-0.190956185716537;-0.295639163439391;-0.387038356718427;0.0322673626110054;-0.362402005710637;0.103679737574351;0.100320403182201;-0.370606352039728;-1.08850969913494;0.314938752714075;1.01346981786077;-0.0314196512080746;0.263015574390605;-0.231470645500017;-0.203969632792467;0.616593766435198;0.432579390555757;0.288199903845187;0.292557703825209;-0.258878108592546;-0.829652519715803;-0.217119063147463;0.952557186745455;0.136611961481123;0.288799121574218;-0.563331487220355;-0.237505706378204;0.131571749843708;-0.0327921588078296;0.318097147903073;0.0749642909809945;0.0342443249401963;-0.174677443224251;0.0138573152154105];

% WTP - jointly:
% WTP_j = [3.19049466659185;1.52249912850195;1.98816163361850;1.51631789608239;2.10998409800909;1.86742915602822;2.81044116550984;1.20537278826101;1.78359111788026;1.54955177109949;2.72378435366689;-0.0791072656166044];
% WTP_se_j = [0.354671693876347;0.159541221147168;0.169892907356082;0.157004428888788;0.171352792234096;0.161923440314132;0.208881698774706;0.156557308631340;0.157385654757847;0.163079708081783;0.198074280889755;0.0941970204212728];
% % WTP - Xm:
% WTP = [Results.MXL.DetailsA(:,1), Results.MXL.DetailsA(:,1) + Results.MXL.DetailsM(:,1), Results.MXL.DetailsA(:,1) + Results.MXL.DetailsM(:,5), Results.MXL.DetailsA(:,1) + Results.MXL.DetailsM(:,9)];
% WTP_se = [Results.MXL.DetailsA(:,3), ...
%     sqrt(Results.MXL.DetailsA(:,3).^2 + Results.MXL.DetailsM(:,3).^2 + 2*diag(Results.MXL.ihess(1:12,91:102))),...
%     sqrt(Results.MXL.DetailsA(:,3).^2 + Results.MXL.DetailsM(:,7).^2 + 2*diag(Results.MXL.ihess(1:12,103:114))),...
%     sqrt(Results.MXL.DetailsA(:,3).^2 + Results.MXL.DetailsM(:,11).^2 + 2*diag(Results.MXL.ihess(1:12,115:126)))];
% pv((WTP_j - WTP),sqrt(WTP_se_j.^2 + WTP_se.^2))
% WTP_pv = pv(WTP(:,1) - [WTP_j,WTP] , sqrt(WTP_se(:,1).^2 + [WTP_se_j,WTP_se].^2))

% WTP-space Y3: -3725.2372
B_backup = [1.51073540305855;0.880361153505576;1.16358831132194;0.932600995901707;1.19660069656000;1.17761443054418;1.78006856821580;0.650890372643339;0.980895447122967;0.997888068252418;1.47565047598405;0.409293026774795;3.24071781372188;0.434494307636114;0.183648172684169;0.0814485845548464;0.208684182685439;0.712730442265366;0.787317515989456;0.529090666782855;0.619629518176448;0.495867273915548;0.320447516946693;-0.0983416589950982;1.25466429936436;1.12027761579504;0.639872357340557;0.838079940502049;0.954110205257661;1.12877952044230;0.339156901977889;0.714969422984136;0.327797890784529;1.02577678783267;-0.794139852506018;0.779897206335402;0.0903274741061899;0.929492201649770;-0.0160372229258335;0.806012757299095;-0.0708495551994492;0.337782493151843;-0.395848759171461;0.138773833583879;0.237849651705810;0.251235995030745;-0.00376680247572788;-0.109814017257205;-0.382563966004041;0.368668960583078;0.115930423842292;0.535303556453991;1.64571880412520;0.372340882139189;0.107698958791710;0.814876478171009;0.788563817707584;0.178153299453198;0.351967193369872;0.241018275894235;-0.124563514628741;0.0252336356594280;-0.0985614080621666;-0.457174892352529;0.113557110160675;-0.0724731520054827;-0.445426711623536;-0.474729556603060;0.0234483401064289;-0.0968276229727440;0.0831416409862032;-0.0652555782897245;0.0426610602131871;0.415862097903775;-0.0125269398413894;0.0322595812523558;0.0605082108116970;0.204469760940579;0.00167589690939559;0.296526873458747;0.136607986597344;0.141314996894166;-0.107076965310944;-0.0767030826799072;0.154020773401000;0.607594216518302;0.175968723128892;0.399284771030014;0.0129043618835342;-0.0679033824609210];
% Xm: -3706.2509
% B_backup = [B_backup; zeros(size(INPUT.Xa,2).*size(INPUT.Xm,2),1)];
% B_backup = [1.69346544770274;1.08764735025440;1.28169804103296;1.14363272511362;1.30107879985998;1.35966231324629;2.05977937574240;0.745730296782698;1.06312358520639;1.22895086247110;1.81418346908463;0.375340573576226;3.03769865482212;0.529492218015486;0.285398987648275;0.105536712210154;0.239401215438940;0.738725672245113;0.885834171213092;0.454111744479180;0.633646395692327;0.454082460601494;0.390245162177089;-0.172034716420403;1.29565541708308;1.23086563860826;0.738872643869973;0.900886292699918;0.900529627747354;1.23614505891232;0.284933988809030;0.634416372964097;0.349365838672220;0.930301235805758;-0.858622614594132;0.699358073810505;0.0633770841381607;0.891534366730227;0.00892508803762767;0.780530994157242;0.000624716856489662;0.327546707007988;-0.380551813081049;0.371927985593053;0.226087923235386;0.148762478580367;-0.126707774648203;0.0873580365744965;-0.234029825175822;0.415271425052949;0.175923083824485;0.581861172133999;1.74244249504711;0.265959316237926;0.166956993196821;0.587218673756951;0.830975523351453;-0.0207438283131503;0.281644817124878;0.400731661119822;-0.0952379916957359;0.00865342202392358;0.426587524809266;0.176552908152435;0.275197470401535;0.218561660518804;-0.109601372769443;-0.182920847381760;-0.0894140207052367;-0.188568328083631;0.118924503389129;0.0360472542716080;-0.0147336722693401;0.434273693600105;0.143813678992953;0.00892641783106688;0.104444355266383;0.201409567623559;0.164073988794947;0.277418398568457;0.0818701465775669;0.109460205792703;0.151445112573017;-0.0236709614504268;0.320135593134484;0.599773193517291;0.332689204606885;0.0777549213793499;-0.00690472869898845;0.0176949669244376;-0.505239798598500;-0.275152903409660;-0.175574329643006;-0.216549566487408;-0.164072926076680;-0.237778614857399;-0.285346185257370;-0.192638218583935;-0.0242383043434697;-0.306823979656237;-0.461709749717368;0.225586176154235;-0.282725020948500;-0.399844858274797;-0.0858349290760834;-0.254980868592023;-0.199966917790959;-0.119257645682281;-0.108867374302109;-0.257190006636825;-0.289451652520341;-0.540994512882569;-0.882215936217435;-0.0784946018563519;0.0121111911520715;-0.0128162215409501;-0.0987985072048690;-0.371587451412083;-0.103186626692927;-0.342283951547115;-0.663555797700381;-0.0694760595397048;-0.107741225481514;-0.188036850003093;-0.0795628980994005;0.172028642188440];


% WTP - Xm:
% WTP = [Results.MXL.DetailsA(:,1), Results.MXL.DetailsA(:,1) + Results.MXL.DetailsM(:,1), Results.MXL.DetailsA(:,1) + Results.MXL.DetailsM(:,5), Results.MXL.DetailsA(:,1) + Results.MXL.DetailsM(:,9)];
% WTP_se = [Results.MXL.DetailsA(:,3), ...
%     sqrt(Results.MXL.DetailsA(:,3).^2 + Results.MXL.DetailsM(:,3).^2 + 2*diag(Results.MXL.ihess(1:12,91:102))),...
%     sqrt(Results.MXL.DetailsA(:,3).^2 + Results.MXL.DetailsM(:,7).^2 + 2*diag(Results.MXL.ihess(1:12,103:114))),...
%     sqrt(Results.MXL.DetailsA(:,3).^2 + Results.MXL.DetailsM(:,11).^2 + 2*diag(Results.MXL.ihess(1:12,115:126)))];
% WTP - jointly:
% WTP_j = [1.51073540304533;0.880361153507941;1.16358831131875;0.932600995912238;1.19660069655578;1.17761443054468;1.78006856822907;0.650890372648122;0.980895447130156;0.997888068263545;1.47565047600225;0.409293026773090];
% WTP_se_j = [0.208576510806571;0.0986762823917876;0.110792292174770;0.105865225143518;0.113130375070439;0.123627274868304;0.136402304206183;0.115944860420316;0.110177173863247;0.115115596750091;0.147844658255421;0.114082362432901];
% Wald test statistic
% WTP_test = (WTP_j - WTP).^2 ./ (WTP_se_j.^2 + WTP_se.^2);
% WTP_pv = chi2cdf(WTP_test,1,'upper')
% pv((WTP_j - WTP),sqrt(WTP_se_j.^2 + WTP_se.^2))
% WTP_pv = pv(WTP(:,1) - [WTP_j,WTP] , sqrt(WTP_se(:,1).^2 + [WTP_se_j,WTP_se].^2))


OptimOpt.Algorithm = 'trust-region'; % 'quasi-newton';
OptimOpt.Hessian = 'user-supplied'; % 'off'

Results.MXL = MXL(INPUT,Results,EstimOpt,OptimOpt);

OptimOpt.Algorithm = 'quasi-newton';
OptimOpt.Hessian = 'off';

Results.MXL = MXL(INPUT,Results,EstimOpt,OptimOpt);


% sendmail('mik@czaj.org','MATLAB: biuro - done!');
%     
% catch theErrorInfo
%     
% sendmail('mik@czaj.org','MATLAB: biuro - error!');
% rethrow(theErrorInfo)
% 
% end